==> core-android-debug-1.12.2-sources.jar: commonMain/io/dyte/core/feat/DyteMeetingParticipant.kt <==
package io.dyte.core.feat

import io.dyte.core.controllers.IControllerContainer
import io.dyte.core.listeners.DyteParticipantUpdateListener
import io.dyte.core.platform.VideoView

/**
 * Dyte meeting participant
 *
 * @property id The ID of the participant pertaining to local user
 * @property userId The userId of the participant.
 * @property name Contains Name of the local user.
 * @property picture The participant's picture (if any).
 * @property isHost
 * @property clientSpecificId  Identifier provided by the developer while adding the participant.
 * @property flags
 * @property audioEnabled A boolean value indicating if the audio currently enabled.
 * @property videoEnabled A boolean value indicating if the video currently enabled.
 * @constructor Create empty Dyte meeting participant
 */
abstract class DyteMeetingParticipant internal constructor(
  open val id: String,
  open val userId: String,
  open val name: String,
  open val picture: String?,
  open val isHost: Boolean,
  open val clientSpecificId: String?,
  open val flags: ParticipantFlags,
  internal val controllerContainer: IControllerContainer
) {
  /**
   * The video track for the local user.
   */
  internal var _videoTrack: Any? = null
  val videoTrack: Any?
    get() = _videoTrack

  /**
   * The audio track for the local user.
   */
  // TODO : add audio track here
  // var audioTrack: Any? = null

  internal var _screenShareTrack: Any? = null
  val screenShareTrack: Any?
    get() = _screenShareTrack

  internal var _audioEnabled: Boolean = false
  val audioEnabled: Boolean
    get() = _audioEnabled

  internal var _videoEnabled: Boolean = false
  val videoEnabled: Boolean
    get() = _videoEnabled

  @Throws(Exception::class)
  open fun disableVideo() {
    controllerContainer.hostController.muteVideo(this)
  }

  open fun toMap(): Map<String, Any?> {
    val map = HashMap<String, Any?>()
    map["id"] = id
    map["userId"] = userId
    map["name"] = name
    map["picture"] = picture
    map["isHost"] = isHost
    map["clientSpecificId"] = clientSpecificId
    map["flags"] = flags.toMap()
    map["audioEnabled"] = audioEnabled
    map["videoEnabled"] = videoEnabled
    return map
  }

  @Throws(Exception::class)
  open fun disableAudio() {
    controllerContainer.hostController.muteAudio(this)
  }

  @Throws(Exception::class)
  open fun kick() {
    controllerContainer.hostController.kick(id)
  }

  @Throws(Exception::class)
  open fun acceptWaitListedRequest() {
    controllerContainer.waitlistController.acceptWaitlistedRequest(this)
  }

  @Throws(Exception::class)
  open fun rejectWaitListedRequest() {
    controllerContainer.waitlistController.rejectWaitlistedRequest(this)
  }

  @Throws(Exception::class)
  open fun pin() {
    controllerContainer.hostController.pinParticipant(this)
  }

  @Throws(Exception::class)
  open fun unpin() {
    controllerContainer.hostController.unpinParticipant()
  }

  val isPinned: Boolean
    get() = controllerContainer.participantController.pinnedParticipant?.id == this.id

  fun addParticipantUpdateListener(participantUpdateListener: DyteParticipantUpdateListener) {
    controllerContainer.eventController.addParticipantUpdateListener(
      this,
      participantUpdateListener
    )
  }

  fun removeParticipantUpdateListener(participantUpdateListener: DyteParticipantUpdateListener) {
    controllerContainer.eventController.removeParticipantUpdateListener(
      this,
      participantUpdateListener
    )
  }

  fun removeParticipantUpdateListeners() {
    controllerContainer.eventController.removeParticipantUpdateListeners(this)
  }

  fun getVideoView(): VideoView {
    return controllerContainer.participantController.getVideoView(this)
  }

  fun getScreenShareVideoView(): VideoView {
    return controllerContainer.participantController.getScreenShareView(this)
  }
}

data class ParticipantFlags(
  val recorder: Boolean,
  val hiddenParticipant: Boolean
) {
  fun toMap(): Map<String, Any?> {
    val map = HashMap<String, Any?>()
    map["recorder"] = recorder
    map["hiddenParticipant"] = hiddenParticipant
    return map
  }
}

==> core-android-debug-1.13.0-sources.jar: commonMain/io/dyte/core/feat/DyteMeetingParticipant.kt <==
package io.dyte.core.feat

import io.dyte.core.controllers.IControllerContainer
import io.dyte.core.listeners.DyteParticipantUpdateListener
import io.dyte.core.platform.VideoView
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.launch
import kotlinx.coroutines.newSingleThreadContext

/**
 * Dyte meeting participant
 *
 * @property id The ID of the participant pertaining to local user
 * @property userId The userId of the participant.
 * @property name Contains Name of the local user.
 * @property picture The participant's picture (if any).
 * @property isHost
 * @property clientSpecificId  Identifier provided by the developer while adding the participant.
 * @property flags
 * @property audioEnabled A boolean value indicating if the audio currently enabled.
 * @property videoEnabled A boolean value indicating if the video currently enabled.
 * @constructor Create empty Dyte meeting participant
 */
abstract class DyteMeetingParticipant internal constructor(
  open val id: String,
  open val userId: String,
  open val name: String,
  open val picture: String?,
  open val isHost: Boolean,
  open val clientSpecificId: String?,
  open val flags: ParticipantFlags,
  internal val controllerContainer: IControllerContainer
) {
  /**
   * The video track for the local user.
   */
  internal var _videoTrack: Any? = null
  val videoTrack: Any?
    get() = _videoTrack

  /**
   * The audio track for the local user.
   */
  // TODO : add audio track here
  // var audioTrack: Any? = null

  internal var _screenShareTrack: Any? = null
  val screenShareTrack: Any?
    get() = _screenShareTrack

  internal var _audioEnabled: Boolean = false
  val audioEnabled: Boolean
    get() = fetchAudioEnabled()

  internal var _videoEnabled: Boolean = false
  val videoEnabled: Boolean
    get() = fetchVideoEnabled()
  protected  val serialScope = CoroutineScope(newSingleThreadContext("DyteMeetingParticipant"))

 protected open fun fetchVideoEnabled(): Boolean {
    return _videoEnabled
  }
    protected  open  fun fetchAudioEnabled(): Boolean {
        return _audioEnabled
    }
  @Throws(Exception::class)
  open fun disableVideo() {
    serialScope.launch {
      controllerContainer.hostController.muteVideo(this@DyteMeetingParticipant)
    }
  }

  open fun toMap(): Map<String, Any?> {
    val map = HashMap<String, Any?>()
    map["id"] = id
    map["userId"] = userId
    map["name"] = name
    map["picture"] = picture
    map["isHost"] = isHost
    map["clientSpecificId"] = clientSpecificId
    map["flags"] = flags.toMap()
    map["audioEnabled"] = audioEnabled
    map["videoEnabled"] = videoEnabled
    return map
  }

  @Throws(Exception::class)
  open fun disableAudio() {
    val self = this
    serialScope.launch {
      controllerContainer.hostController.muteAudio(self)
    }
  }

  @Throws(Exception::class)
  open fun kick() {
    serialScope.launch {
    controllerContainer.hostController.kick(id)
    }
  }

  @Throws(Exception::class)
  open fun acceptWaitListedRequest() {
    serialScope.launch {
    controllerContainer.waitlistController.acceptWaitlistedRequest(this@DyteMeetingParticipant)
    }
  }

  @Throws(Exception::class)
  open fun rejectWaitListedRequest() {
    val self = this
    serialScope.launch {
      controllerContainer.waitlistController.rejectWaitlistedRequest(self)
    }
  }

  @Throws(Exception::class)
  open fun pin() {
    serialScope.launch {
      controllerContainer.hostController.pinParticipant(this@DyteMeetingParticipant)
    }
  }

  @Throws(Exception::class)
  open fun unpin() {
    serialScope.launch {
      controllerContainer.hostController.unpinParticipant()
    }
  }

  val isPinned: Boolean
    get() = controllerContainer.participantController.pinnedParticipant?.id == this.id

  fun addParticipantUpdateListener(participantUpdateListener: DyteParticipantUpdateListener) {
    val self = this
    serialScope.launch {
      controllerContainer.eventController.addParticipantUpdateListener(
        self,
        participantUpdateListener
      )
    }
  }

  fun removeParticipantUpdateListener(participantUpdateListener: DyteParticipantUpdateListener) {
    serialScope.launch {
      controllerContainer.eventController.removeParticipantUpdateListener(
        this@DyteMeetingParticipant,
        participantUpdateListener
      )
    }
  }

  fun removeParticipantUpdateListeners() {
    controllerContainer.eventController.removeParticipantUpdateListeners(this)
  }

  open fun getVideoView(): VideoView? {
    return controllerContainer.participantController.getVideoView(this)
  }

  fun getScreenShareVideoView(): VideoView {
    return controllerContainer.participantController.getScreenShareView(this)
  }
}

data class ParticipantFlags(
  val recorder: Boolean,
  val hiddenParticipant: Boolean
) {
  fun toMap(): Map<String, Any?> {
    val map = HashMap<String, Any?>()
    map["recorder"] = recorder
    map["hiddenParticipant"] = hiddenParticipant
    return map
  }
}
